@@ -1,11 +1,10 @@
-import httplib,xmpp
 from ..exceptions import MonitorException
 import logging
 
 __author__ = 'leifj'
 
 
-def check_http(host, vhost=None, url=None, match=None):
+def _check_http(host, vhost=None, url=None, match=None):
     logging.debug("HTTP connection to %s" % host)
     h = httplib.HTTPConnection(host)
     logging.debug("GET %s (vhost=%s)" % (url, vhost))
@@ -22,8 +21,15 @@ def check_http(host, vhost=None, url=None, match=None):
     else:
         return True
 
+check_http = None
+try: 
+    import httplib
+    check_http = _check_http
+except ImportError:
+    logging.debug("Missing httplib - not providing check_http")
 
-def check_xmpp(host, port=5222, jid=None, password=None):
+
+def _check_xmpp(host, port=5222, jid=None, password=None):
     logging.debug("XMPP connection to %s" % host)
     jID = xmpp.protocol.JID(jid)
     cl = xmpp.Client((host, port), debug=[])
@@ -33,4 +39,11 @@ def check_xmpp(host, port=5222, jid=None, password=None):
     auth = cl.auth(jID.getNode(), password, jID.getResource())
     if not auth:
         raise MonitorException("Authentication failed")
-    return True
\ No newline at end of file
+    return True
+
+check_xmpp = None
+try:
+    import xmpp 
+    check_xmpp = _check_xmpp
+except ImportError:
+    logging.debug("Missing xmpppy - not providing check_xmpp")
